%global mingw_build_ucrt64 1
# The mingw-w64-headers provide the headers pthread_time.h
# and pthread_unistd.h by default and are dummy headers.
# The real implementation for these headers is in a separate
# library called winpthreads. As long as winpthreads isn't
# build, the flag below needs to be set to 1. When winpthreads
# is available then this flag needs to be set to 0 to avoid
# a file conflict with the winpthreads headers.
%global bundle_dummy_pthread_headers 0

Name:           mingw-headers
Version:        11.0.1
Release:        %mkrel 1
Summary:        Win32/Win64 header files

License:        Public Domain and LGPLv2+ and ZPLv2.1
Group:          Development/Other
URL:            https://mingw-w64.sourceforge.net/
Source0:        https://downloads.sourceforge.net/mingw-w64/mingw-w64-v%{version}%{?pre:-%{pre}}.tar.bz2

# Our RPM macros automatically set the environment variable WIDL
# This confuses the mingw-headers configure scripts and causes various
# headers to be regenerated from their .idl source. Prevent this from
# happening as the .idl files shouldn't be used by default
Patch0:         mingw-headers-no-widl.patch

BuildArch:      noarch

BuildRequires: make
BuildRequires: mingw32-filesystem >= 133
BuildRequires: mingw64-filesystem >= 133
BuildRequires: ucrt64-filesystem >= 133


%description
MinGW Windows cross-compiler Win32 and Win64 header files.


%package -n mingw32-headers
Summary:        MinGW Windows cross-compiler Win32 header files
Requires:       mingw32-filesystem >= 95
%if 0%{bundle_dummy_pthread_headers} == 0
Requires:       mingw32-winpthreads
%endif

%description -n mingw32-headers
MinGW Windows cross-compiler Win32 header files.

%package -n mingw64-headers
Summary:        MinGW Windows cross-compiler Win64 header files
Requires:       mingw64-filesystem >= 95
%if 0%{bundle_dummy_pthread_headers} == 0
Requires:       mingw64-winpthreads
%endif

%description -n mingw64-headers
MinGW Windows cross-compiler Win64 header files.

%package -n ucrt64-headers
Summary:        MinGW Windows cross-compiler Win64 header files
Requires:       ucrt64-filesystem >= 133
%if 0%{bundle_dummy_pthread_headers} == 0
Requires:       ucrt64-winpthreads
%endif

%description -n ucrt64-headers
MinGW Windows cross-compiler Win64 header files.


%prep
%autosetup -p1 -n mingw-w64-v%{version}%{?pre:-%{pre}}


%build
export UCRT64_CONFIGURE_ARGS="--with-default-msvcrt=ucrt"

pushd mingw-w64-headers
    %mingw_configure --enable-sdk=all --enable-idl
popd


%install
pushd mingw-w64-headers
    %mingw_make_install
popd

# Drop the dummy pthread headers if necessary
%if 0%{?bundle_dummy_pthread_headers} == 0
rm -f %{buildroot}%{mingw32_includedir}/pthread_signal.h
rm -f %{buildroot}%{mingw32_includedir}/pthread_time.h
rm -f %{buildroot}%{mingw32_includedir}/pthread_unistd.h
rm -f %{buildroot}%{mingw64_includedir}/pthread_signal.h
rm -f %{buildroot}%{mingw64_includedir}/pthread_time.h
rm -f %{buildroot}%{mingw64_includedir}/pthread_unistd.h
rm -f %{buildroot}%{ucrt64_includedir}/pthread_signal.h
rm -f %{buildroot}%{ucrt64_includedir}/pthread_time.h
rm -f %{buildroot}%{ucrt64_includedir}/pthread_unistd.h
%endif


%files -n mingw32-headers
%license COPYING DISCLAIMER DISCLAIMER.PD
%{mingw32_includedir}/*

%files -n mingw64-headers
%license COPYING DISCLAIMER DISCLAIMER.PD
%{mingw64_includedir}/*
 
%files -n ucrt64-headers
%license COPYING DISCLAIMER DISCLAIMER.PD
%{ucrt64_includedir}/*



%changelog
* Thu Sep 28 2023 tv <tv> 11.0.1-1.mga10
+ Revision: 1991753
- Update to 11.0.1

* Sun May 08 2022 tv <tv> 10.0.0-7.mga9
+ Revision: 1856752
- Rebuild (bundle_dummy_pthread_headers=0)

* Sun May 08 2022 tv <tv> 10.0.0-6.mga9
+ Revision: 1856735
- Build with dummy pthread headers
- Spec cleanups

* Thu Apr 28 2022 tv <tv> 10.0.0-5.mga9
+ Revision: 1854840
- Update to 10.0.0

* Mon Mar 21 2022 umeabot <umeabot> 9.0.0-5.mga9
+ Revision: 1816507
- Mageia 9 Mass Rebuild

* Wed Mar 02 2022 tv <tv> 9.0.0-4.mga9
+ Revision: 1787776
- Add ucrt64 target (bundle_dummy_pthread_headers=0, +Requires: winpthread)

* Tue Mar 01 2022 tv <tv> 9.0.0-3.mga9
+ Revision: 1787239
- Add ucrt64 target (bundle_dummy_pthread_headers=0, -Requires: winpthread)

* Tue Mar 01 2022 tv <tv> 9.0.0-2.mga9
+ Revision: 1787034
- Add ucrt64 target (bundle_dummy_pthread_headers=1)

* Fri Oct 22 2021 tv <tv> 9.0.0-1.mga9
+ Revision: 1752605
- Update to 9.0.0

* Mon Nov 02 2020 akien <akien> 8.0.0-1.mga8
+ Revision: 1641654
- Version 8.0.0

* Thu Sep 24 2020 tv <tv> 7.0.0-1.mga8
+ Revision: 1629799
- 7.0.0
+ danf <danf>
- Switch URLs from http: to https:

* Sat Feb 15 2020 umeabot <umeabot> 6.0.0-2.mga8
+ Revision: 1526924
- Mageia 8 Mass Rebuild

* Sat Jul 06 2019 daviddavid <daviddavid> 6.0.0-1.mga8
+ Revision: 1418947
- new version: 6.0.0

* Thu Sep 20 2018 umeabot <umeabot> 5.0.4-2.mga7
+ Revision: 1279826
- Mageia 7 Mass Rebuild

* Sun Jul 22 2018 daviddavid <daviddavid> 5.0.4-1.mga7
+ Revision: 1244777
- new version: 5.0.4

* Thu Jan 26 2017 akien <akien> 5.0.1-1.mga6
+ Revision: 1083489
- Sync with Fedora: Thu Jan 26 2017 Kalev Lember <klember@redhat.com> - 5.0.1-1
  o Update to 5.0.1
  o Use license macro
  o Backported patch to build failure of latest wine-gecko

* Tue Apr 05 2016 tv <tv> 5.0-0.1.rc2.mga6
+ Revision: 998604
- new release

* Sun Jan 31 2016 umeabot <umeabot> 3.0.0-7.mga6
+ Revision: 929486
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.0.0-6.mga5
+ Revision: 750620
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.0.0-5.mga5
+ Revision: 682460
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.0.0-4.mga4
+ Revision: 536097
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 3.0.0-3.mga4
+ Revision: 483330
- Disable bootstrap

* Sun Sep 22 2013 neoclust <neoclust> 3.0.0-2.mga4
+ Revision: 483204
- Invers logic about buildrequires

* Sun Sep 22 2013 neoclust <neoclust> 3.0.0-1.mga4
+ Revision: 483191
- imported package mingw-headers

